==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "Tijdframe"

, "summary"
: "samenvatting"

, "Total Timesheets"
: "Alle urenstaten"

, "Billable Timesheets"
: "Facturabele urenstaten"

, "Total Time"
: "Totale tijd"

, "Time of Billable Timesheets"
: "Tijd van facturabele urenstaten"

, "Description"
: "Beschrijving"

, "Detail"
: "Details"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exporteer urenstaten"

, "Export as ODS"
: "Exporteer als ODS"

, "Export as CSV"
: "Exporteer als CSV"

, "Export as ..."
: "Exporteer als ..."

, "Timesheet, Timesheets"
: [
  ""
 ,""

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Niet gelukt"

, "Could not save {0}."
: "Opslaan mislukt {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Booking deadline voor dit tijdaccount is verlopen."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Contract"

, "without contract"
: "zonder contract"

, "Add New Timeaccount"
: "Nieuw urenaccount toevoegen"

, "Unit"
: "Eenheid"

, "Unit Price"
: "Eenheidsprijs"

, "Factor"
: ""

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "gesloten"

, "open"
: "open"

, "Cleared In"
: "Afgemaakt in"

, "Cleared at"
: "Afgemaakt op"

, "Cost Center"
: "Kostenplaats"

, "Responsible Person"
: "Verantwoordelijke persoon"

, "Timesheets are billable"
: "Urenstaten zijn facturabel"

, "Invoice"
: "Factuur"

, "Time Account, Time Accounts"
: [
  ""
 ,""

]
, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Access"
: "Toegang"

, "Permissions"
: "Permissies"

, "Time Account - Billed"
: "Urenaccount - Gefactureerd"

, "not yet billed"
: "Nog niet gefactureerd"

, "to bill"
: "Factureren"

, "billed"
: "Gefactureerd"

, "Time Account - Status"
: "Urenaccount - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Boek eigen"

, "The grant to add Timesheets to this Timeaccount"
: "Het recht om urenstaten aan dit Urenaccount toe te voegen"

, "View All"
: "Bekijk alle"

, "The grant to view Timesheets of other users"
: "Het recht om urenstaten van andere gebruikers in te zien"

, "Book All"
: "Boek alle"

, "The grant to add Timesheets for other users"
: "Het recht om urenstaten voor andere gebruikers toe te voegen"

, "Manage Clearing"
: "Beheer opschonen"

, "The grant to manage clearing of Timesheets"
: "Het recht om urenstaten op te schonen"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Zet gesloten"

, "Timesheets ODS export configuration"
: "Urenstaten export in ODS configureren "

, "Use this configuration for the timesheet ODS export."
: "Gebruik deze configuratie voor de export naar ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "standaard"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "Geen"

, "last week"
: "vorige week"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Afgemaakt in"

, "Billed"
: "Gefactureerd"

, "Booking deadline"
: "Reserverings deadline"

, "Accounting time factor"
: ""

, "hour"
: "uur"

, "Account"
: "Account"

, "Time Account (Number - Title)"
: "Tijd Account (Nummer - Titel)"

, "Billable"
: "Facturabel"

, "Cleared"
: "Afgemaakt"

, "Date"
: "Datum"

, "Start time"
: "Start tijd"

, "End time"
: ""

, "Duration"
: "Duur"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Tijd Account gesloten"

, "Timetracker"
: "Tijdregistratie"

, "Timeaccounts to bill"
: "Te factureren tijdaccounts"

, "Timeaccounts not yet billed"
: "Tijdaccounts nog niet gefactureerd"

, "Timeaccounts already billed"
: "Tijdaccounts al gefactureerd"

, "My Timesheets today"
: "Mijn urenstaten van vandaag"

, "My Timesheets this week"
: "Mijn urenstaten van deze week"

, "My Timesheets last week"
: "Mijn urenstaten van vorige week"

, "My Timesheets this month"
: "Mijn urenstaten van deze maand"

, "My Timesheets last month"
: "Mijn urenstaten van vorige maand"

, "Manage timeaccounts"
: "Beheer tijdaccounts"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Voeg toe, bewerk of verwijder urenstaten (inclusief alle rechten)"

, "Add timeaccounts"
: "Urenstaat toevoegen"

, "Manage shared timeaccount favorites"
: "Beheer gedeelde favoriete urenaccounts"

, "Create or update shared timeaccount favorites"
: "Maak of update gedeelde favoriete urenaccounts"

, "Manage shared timesheet favorites"
: "Beheer gedeelde favoriete urenstaten"

, "Create or update shared timesheet favorites"
: "Maak of update gedeelde favoriete urenstaten"






, "Timesheet"
: ""

, "Timeaccount"
: ""

, "Time Account"
: ""

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "Tijdframe"

, "summary"
: "samenvatting"

, "Total Timesheets"
: "Alle urenstaten"

, "Billable Timesheets"
: "Facturabele urenstaten"

, "Total Time"
: "Totale tijd"

, "Time of Billable Timesheets"
: "Tijd van facturabele urenstaten"

, "Description"
: "Beschrijving"

, "Detail"
: "Details"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exporteer urenstaten"

, "Export as ODS"
: "Exporteer als ODS"

, "Export as CSV"
: "Exporteer als CSV"

, "Export as ..."
: "Exporteer als ..."

, "Timesheet, Timesheets"
: [
  ""
 ,""

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Niet gelukt"

, "Could not save {0}."
: "Opslaan mislukt {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Booking deadline voor dit tijdaccount is verlopen."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Contract"

, "without contract"
: "zonder contract"

, "Add New Timeaccount"
: "Nieuw urenaccount toevoegen"

, "Unit"
: "Eenheid"

, "Unit Price"
: "Eenheidsprijs"

, "Factor"
: ""

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "gesloten"

, "open"
: "open"

, "Cleared In"
: "Afgemaakt in"

, "Cleared at"
: "Afgemaakt op"

, "Cost Center"
: "Kostenplaats"

, "Responsible Person"
: "Verantwoordelijke persoon"

, "Timesheets are billable"
: "Urenstaten zijn facturabel"

, "Invoice"
: "Factuur"

, "Time Account, Time Accounts"
: [
  ""
 ,""

]
, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Access"
: "Toegang"

, "Permissions"
: "Permissies"

, "Time Account - Billed"
: "Urenaccount - Gefactureerd"

, "not yet billed"
: "Nog niet gefactureerd"

, "to bill"
: "Factureren"

, "billed"
: "Gefactureerd"

, "Time Account - Status"
: "Urenaccount - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Boek eigen"

, "The grant to add Timesheets to this Timeaccount"
: "Het recht om urenstaten aan dit Urenaccount toe te voegen"

, "View All"
: "Bekijk alle"

, "The grant to view Timesheets of other users"
: "Het recht om urenstaten van andere gebruikers in te zien"

, "Book All"
: "Boek alle"

, "The grant to add Timesheets for other users"
: "Het recht om urenstaten voor andere gebruikers toe te voegen"

, "Manage Clearing"
: "Beheer opschonen"

, "The grant to manage clearing of Timesheets"
: "Het recht om urenstaten op te schonen"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Zet gesloten"

, "Timesheets ODS export configuration"
: "Urenstaten export in ODS configureren "

, "Use this configuration for the timesheet ODS export."
: "Gebruik deze configuratie voor de export naar ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "standaard"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "Geen"

, "last week"
: "vorige week"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Afgemaakt in"

, "Billed"
: "Gefactureerd"

, "Booking deadline"
: "Reserverings deadline"

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: "uur"

, "Account"
: "Account"

, "Time Account (Number - Title)"
: "Tijd Account (Nummer - Titel)"

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "Facturabel"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "Datum"

, "Start time"
: "Start tijd"

, "End time"
: ""

, "Duration"
: "Duur"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: "Tijdregistratie"

, "My Timesheets today"
: "Mijn urenstaten van vandaag"

, "My Timesheets this week"
: "Mijn urenstaten van deze week"

, "My Timesheets last week"
: "Mijn urenstaten van vorige week"

, "My Timesheets this month"
: "Mijn urenstaten van deze maand"

, "My Timesheets last month"
: "Mijn urenstaten van vorige maand"

, "Timeaccounts to bill"
: "Te factureren tijdaccounts"

, "Timeaccounts not yet billed"
: "Tijdaccounts nog niet gefactureerd"

, "Timeaccounts already billed"
: "Tijdaccounts al gefactureerd"

, "Manage timeaccounts"
: "Beheer tijdaccounts"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Voeg toe, bewerk of verwijder urenstaten (inclusief alle rechten)"

, "Add timeaccounts"
: "Urenstaat toevoegen"

, "Manage shared timeaccount favorites"
: "Beheer gedeelde favoriete urenaccounts"

, "Create or update shared timeaccount favorites"
: "Maak of update gedeelde favoriete urenaccounts"

, "Manage shared timesheet favorites"
: "Beheer gedeelde favoriete urenstaten"

, "Create or update shared timesheet favorites"
: "Maak of update gedeelde favoriete urenstaten"








, "Timesheet"
: ""

, "Timeaccount"
: ""

, "Time Account"
: ""

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
